# py-SUbyT

  A <u>Py</u>thon library for <u>S</u>emantic <u>U</u>plifting <u>by</u> <u>T</u>emplates.

  An easy way (through python) to produce Linked Data
  (aka semantic uplifting)
  from classic data files (CSV, XML, JSON) into triples (RDF, turtle)
  through jinja-Templating

### Usage and further reading

Please check out the Py-SUbyt documentation. Namely:
- the [user guide](./docs/cli.md)
- the supported [features](./docs/features.md)
- the [examples](./docs/examples.md)
- and the [style guide](./docs/cli-style.md)!


<p align="center">
<a href="https://github.com/JotaFan/pycoverage"><img src="https://github.com/vliz-be-opsci/pysubyt/tree/gh-pages/coverage.svg"></a>
<a href="https://github.com/psf/black"><img alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg"></a>
</p>